diff decoders/shn.c @ 221:c9772a9f5271

Initial implementation or stubs for rewind method. Other cleanups.
author Ryan C. Gordon <icculus@icculus.org>
date Thu, 17 Jan 2002 20:53:53 +0000
parents 8c2cb920a383
children 15a3b1a1291c
line wrap: on
line diff
--- a/decoders/shn.c	Thu Jan 17 20:53:03 2002 +0000
+++ b/decoders/shn.c	Thu Jan 17 20:53:53 2002 +0000
@@ -66,6 +66,7 @@
 static int SHN_open(Sound_Sample *sample, const char *ext);
 static void SHN_close(Sound_Sample *sample);
 static Uint32 SHN_read(Sound_Sample *sample);
+static int SHN_rewind(Sound_Sample *sample);
 
 static const char *extensions_shn[] = { "SHN", NULL };
 const Sound_DecoderFunctions __Sound_DecoderFunctions_SHN =
@@ -77,11 +78,12 @@
         "http://www.icculus.org/SDL_sound/"
     },
 
-    SHN_init,       /* init() method       */
-    SHN_quit,       /* quit() method       */
-    SHN_open,       /* open() method       */
-    SHN_close,      /* close() method       */
-    SHN_read        /* read() method       */
+    SHN_init,       /*   init() method */
+    SHN_quit,       /*   quit() method */
+    SHN_open,       /*   open() method */
+    SHN_close,      /*  close() method */
+    SHN_read,       /*   read() method */
+    SHN_rewind      /* rewind() method */
 };
 
 
@@ -1296,6 +1298,15 @@
     return(retval);
 } /* SHN_read */
 
+
+static int SHN_rewind(Sound_Sample *sample)
+{
+    /* !!! FIXME. */
+    SNDDBG(("SHN_rewind(): Write me!\n"));
+    assert(0);
+    return(0);
+} /* SHN_rewind */
+
 #endif  /* defined SOUND_SUPPORTS_SHN */
 
 /* end of shn.c ... */